@@ -20,17 +20,16 @@ impl Cli {
     }
 
     pub fn run(&self) {
+        let mut lemmy = LemmyHelp::new();
+
         // NOTE: can we use threads? but if so, what about ordering?
         for f in &self.files {
-            let nodes = {
-                let source = read_to_string(f).unwrap();
-                let source = Lua::parse(&source).unwrap();
-                LemmyHelp::parse(&source).unwrap()
-            };
-
-            print!("{nodes}");
+            let source = read_to_string(f).unwrap();
+            let source = Lua::parse(&source).unwrap();
+            lemmy.for_help(&source).unwrap();
         }
 
+        print!("{lemmy}");
         println!("vim:tw=78:ts=8:noet:ft=help:norl:");
     }
 }
